"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aptos_client_1 = require("./aptos_client");
const nodeUrl = "https://fullnode.devnet.aptoslabs.com";
test("gets genesis account", async () => {
    const client = new aptos_client_1.AptosClient(nodeUrl);
    const account = await client.getAccount("0x1");
    expect(account.authentication_key.length).toBe(66);
    expect(account.sequence_number).not.toBeNull();
});
test("gets genesis resources", async () => {
    const client = new aptos_client_1.AptosClient(nodeUrl);
    const resources = await client.getAccountResources("0x1");
    const accountResource = resources.find((r) => r.type === "0x1::Account::Account");
    expect(accountResource.data["self_address"]).toBe("0x1");
});
test("gets account modules", async () => {
    const client = new aptos_client_1.AptosClient(nodeUrl);
    const modules = await client.getAccountModules("0x1");
    const module = modules.find((r) => r.abi.name === "TestCoin");
    expect(module.abi.address).toBe("0x1");
});
test("test raiseForStatus", async () => {
    const testData = { "hello": "wow" };
    const fakeResponse = {
        status: 200,
        statusText: "Status Text",
        data: "some string",
        request: {
            host: "host",
            path: "/path"
        },
    };
    // Shouldn't throw
    (0, aptos_client_1.raiseForStatus)(200, fakeResponse, testData);
    (0, aptos_client_1.raiseForStatus)(200, fakeResponse);
    // an error, oh no!
    fakeResponse.status = 500;
    expect(() => (0, aptos_client_1.raiseForStatus)(200, fakeResponse, testData))
        .toThrow("Status Text - \"some string\" @ host/path : {\"hello\":\"wow\"}");
    expect(() => (0, aptos_client_1.raiseForStatus)(200, fakeResponse))
        .toThrow("Status Text - \"some string\" @ host/path");
    // Just a wild test to make sure it doesn't break: request is `any`!
    delete fakeResponse.request;
    expect(() => (0, aptos_client_1.raiseForStatus)(200, fakeResponse, testData))
        .toThrow("Status Text - \"some string\" : {\"hello\":\"wow\"}");
    expect(() => (0, aptos_client_1.raiseForStatus)(200, fakeResponse))
        .toThrow("Status Text - \"some string\"");
});
//# sourceMappingURL=aptos_client.test.js.map